# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/cluster/v4alpha/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.cluster.v4alpha import circuit_breaker_pb2 as envoy_dot_config_dot_cluster_dot_v4alpha_dot_circuit__breaker__pb2
from envoy.config.cluster.v4alpha import filter_pb2 as envoy_dot_config_dot_cluster_dot_v4alpha_dot_filter__pb2
from envoy.config.cluster.v4alpha import outlier_detection_pb2 as envoy_dot_config_dot_cluster_dot_v4alpha_dot_outlier__detection__pb2
from envoy.config.core.v4alpha import address_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2
from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.core.v4alpha import config_source_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2
from envoy.config.core.v4alpha import extension_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2
from envoy.config.core.v4alpha import health_check_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_health__check__pb2
from envoy.config.endpoint.v3 import endpoint_pb2 as envoy_dot_config_dot_endpoint_dot_v3_dot_endpoint__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.core.v3 import collection_entry_pb2 as xds_dot_core_dot_v3_dot_collection__entry__pb2
from udpa.annotations import security_pb2 as udpa_dot_annotations_dot_security__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/cluster/v4alpha/cluster.proto',
  package='envoy.config.cluster.v4alpha',
  syntax='proto3',
  serialized_options=b'\n*io.envoyproxy.envoy.config.cluster.v4alphaB\014ClusterProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*envoy/config/cluster/v4alpha/cluster.proto\x12\x1c\x65nvoy.config.cluster.v4alpha\x1a\x32\x65nvoy/config/cluster/v4alpha/circuit_breaker.proto\x1a)envoy/config/cluster/v4alpha/filter.proto\x1a\x34\x65nvoy/config/cluster/v4alpha/outlier_detection.proto\x1a\'envoy/config/core/v4alpha/address.proto\x1a$envoy/config/core/v4alpha/base.proto\x1a-envoy/config/core/v4alpha/config_source.proto\x1a)envoy/config/core/v4alpha/extension.proto\x1a,envoy/config/core/v4alpha/health_check.proto\x1a\'envoy/config/endpoint/v3/endpoint.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\"xds/core/v3/collection_entry.proto\x1a\x1fudpa/annotations/security.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"t\n\x11\x43lusterCollection\x12-\n\x07\x65ntries\x18\x01 \x01(\x0b\x32\x1c.xds.core.v3.CollectionEntry:0\x9a\xc5\x88\x1e+\n)envoy.config.cluster.v3.ClusterCollection\"\xfa;\n\x07\x43luster\x12\\\n\x18transport_socket_matches\x18+ \x03(\x0b\x32:.envoy.config.cluster.v4alpha.Cluster.TransportSocketMatch\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\ralt_stat_name\x18\x1c \x01(\t\x12M\n\x04type\x18\x02 \x01(\x0e\x32\x33.envoy.config.cluster.v4alpha.Cluster.DiscoveryTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01H\x00\x12O\n\x0c\x63luster_type\x18& \x01(\x0b\x32\x37.envoy.config.cluster.v4alpha.Cluster.CustomClusterTypeH\x00\x12R\n\x12\x65\x64s_cluster_config\x18\x03 \x01(\x0b\x32\x36.envoy.config.cluster.v4alpha.Cluster.EdsClusterConfig\x12<\n\x0f\x63onnect_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12P\n!per_connection_buffer_limit_bytes\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\x8a\x93\xb7*\x02\x10\x01\x12M\n\tlb_policy\x18\x06 \x01(\x0e\x32..envoy.config.cluster.v4alpha.Cluster.LbPolicyB\n\xfa\x42\x07\x82\x01\x04\x10\x01 \x07\x12H\n\x0fload_assignment\x18! \x01(\x0b\x32/.envoy.config.endpoint.v3.ClusterLoadAssignment\x12=\n\rhealth_checks\x18\x08 \x03(\x0b\x32&.envoy.config.core.v4alpha.HealthCheck\x12\x41\n\x1bmax_requests_per_connection\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12G\n\x10\x63ircuit_breakers\x18\n \x01(\x0b\x32-.envoy.config.cluster.v4alpha.CircuitBreakers\x12r\n typed_extension_protocol_options\x18$ \x03(\x0b\x32H.envoy.config.cluster.v4alpha.Cluster.TypedExtensionProtocolOptionsEntry\x12\x41\n\x10\x64ns_refresh_rate\x18\x10 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06*\x04\x10\xc0\x84=\x12S\n\x18\x64ns_failure_refresh_rate\x18, \x01(\x0b\x32\x31.envoy.config.cluster.v4alpha.Cluster.RefreshRate\x12\x17\n\x0frespect_dns_ttl\x18\' \x01(\x08\x12Z\n\x11\x64ns_lookup_family\x18\x11 \x01(\x0e\x32\x35.envoy.config.cluster.v4alpha.Cluster.DnsLookupFamilyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x39\n\rdns_resolvers\x18\x12 \x03(\x0b\x32\".envoy.config.core.v4alpha.Address\x12\x1f\n\x17use_tcp_for_dns_lookups\x18- \x01(\x08\x12I\n\x11outlier_detection\x18\x13 \x01(\x0b\x32..envoy.config.cluster.v4alpha.OutlierDetection\x12=\n\x10\x63leanup_interval\x18\x14 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x43\n\x14upstream_bind_config\x18\x15 \x01(\x0b\x32%.envoy.config.core.v4alpha.BindConfig\x12N\n\x10lb_subset_config\x18\x16 \x01(\x0b\x32\x34.envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig\x12U\n\x13ring_hash_lb_config\x18\x17 \x01(\x0b\x32\x36.envoy.config.cluster.v4alpha.Cluster.RingHashLbConfigH\x01\x12P\n\x10maglev_lb_config\x18\x34 \x01(\x0b\x32\x34.envoy.config.cluster.v4alpha.Cluster.MaglevLbConfigH\x01\x12[\n\x16original_dst_lb_config\x18\" \x01(\x0b\x32\x39.envoy.config.cluster.v4alpha.Cluster.OriginalDstLbConfigH\x01\x12]\n\x17least_request_lb_config\x18% \x01(\x0b\x32:.envoy.config.cluster.v4alpha.Cluster.LeastRequestLbConfigH\x01\x12N\n\x10\x63ommon_lb_config\x18\x1b \x01(\x0b\x32\x34.envoy.config.cluster.v4alpha.Cluster.CommonLbConfig\x12\x44\n\x10transport_socket\x18\x18 \x01(\x0b\x32*.envoy.config.core.v4alpha.TransportSocket\x12\x35\n\x08metadata\x18\x19 \x01(\x0b\x32#.envoy.config.core.v4alpha.Metadata\x12\\\n\x1bupstream_connection_options\x18\x1e \x01(\x0b\x32\x37.envoy.config.cluster.v4alpha.UpstreamConnectionOptions\x12\x30\n(close_connections_on_host_health_failure\x18\x1f \x01(\x08\x12%\n\x1dignore_health_on_host_removal\x18  \x01(\x08\x12\x35\n\x07\x66ilters\x18( \x03(\x0b\x32$.envoy.config.cluster.v4alpha.Filter\x12P\n\x15load_balancing_policy\x18) \x01(\x0b\x32\x31.envoy.config.cluster.v4alpha.LoadBalancingPolicy\x12;\n\nlrs_server\x18* \x01(\x0b\x32\'.envoy.config.core.v4alpha.ConfigSource\x12H\n\x0fupstream_config\x18\x30 \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfig\x12L\n\x13track_cluster_stats\x18\x31 \x01(\x0b\x32/.envoy.config.cluster.v4alpha.TrackClusterStats\x12Q\n\x11preconnect_policy\x18\x32 \x01(\x0b\x32\x36.envoy.config.cluster.v4alpha.Cluster.PreconnectPolicy\x12\x31\n)connection_pool_per_downstream_connection\x18\x33 \x01(\x08\x1a\xd8\x01\n\x14TransportSocketMatch\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12&\n\x05match\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x44\n\x10transport_socket\x18\x03 \x01(\x0b\x32*.envoy.config.core.v4alpha.TransportSocket:;\x9a\xc5\x88\x1e\x36\n4envoy.config.cluster.v3.Cluster.TransportSocketMatch\x1a\x90\x01\n\x11\x43ustomClusterType\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12*\n\x0ctyped_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:8\x9a\xc5\x88\x1e\x33\n1envoy.config.cluster.v3.Cluster.CustomClusterType\x1a\x9e\x01\n\x10\x45\x64sClusterConfig\x12;\n\neds_config\x18\x01 \x01(\x0b\x32\'.envoy.config.core.v4alpha.ConfigSource\x12\x14\n\x0cservice_name\x18\x02 \x01(\t:7\x9a\xc5\x88\x1e\x32\n0envoy.config.cluster.v3.Cluster.EdsClusterConfig\x1a\xb3\x07\n\x0eLbSubsetConfig\x12n\n\x0f\x66\x61llback_policy\x18\x01 \x01(\x0e\x32K.envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.LbSubsetFallbackPolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12/\n\x0e\x64\x65\x66\x61ult_subset\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12_\n\x10subset_selectors\x18\x03 \x03(\x0b\x32\x45.envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.LbSubsetSelector\x12\x1d\n\x15locality_weight_aware\x18\x04 \x01(\x08\x12\x1d\n\x15scale_locality_weight\x18\x05 \x01(\x08\x12\x16\n\x0epanic_mode_any\x18\x06 \x01(\x08\x12\x13\n\x0blist_as_any\x18\x07 \x01(\x08\x1a\xab\x03\n\x10LbSubsetSelector\x12\x0c\n\x04keys\x18\x01 \x03(\t\x12\x1e\n\x16single_host_per_subset\x18\x04 \x01(\x08\x12\x87\x01\n\x0f\x66\x61llback_policy\x18\x02 \x01(\x0e\x32\x64.envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.LbSubsetSelector.LbSubsetSelectorFallbackPolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x1c\n\x14\x66\x61llback_keys_subset\x18\x03 \x03(\t\"y\n\x1eLbSubsetSelectorFallbackPolicy\x12\x0f\n\x0bNOT_DEFINED\x10\x00\x12\x0f\n\x0bNO_FALLBACK\x10\x01\x12\x10\n\x0c\x41NY_ENDPOINT\x10\x02\x12\x12\n\x0e\x44\x45\x46\x41ULT_SUBSET\x10\x03\x12\x0f\n\x0bKEYS_SUBSET\x10\x04:F\x9a\xc5\x88\x1e\x41\n?envoy.config.cluster.v3.Cluster.LbSubsetConfig.LbSubsetSelector\"O\n\x16LbSubsetFallbackPolicy\x12\x0f\n\x0bNO_FALLBACK\x10\x00\x12\x10\n\x0c\x41NY_ENDPOINT\x10\x01\x12\x12\n\x0e\x44\x45\x46\x41ULT_SUBSET\x10\x02:5\x9a\xc5\x88\x1e\x30\n.envoy.config.cluster.v3.Cluster.LbSubsetConfig\x1a\xd7\x01\n\x14LeastRequestLbConfig\x12;\n\x0c\x63hoice_count\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x02\x12\x45\n\x13\x61\x63tive_request_bias\x18\x02 \x01(\x0b\x32(.envoy.config.core.v4alpha.RuntimeDouble:;\x9a\xc5\x88\x1e\x36\n4envoy.config.cluster.v3.Cluster.LeastRequestLbConfig\x1a\xf1\x02\n\x10RingHashLbConfig\x12\x43\n\x11minimum_ring_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\n\xfa\x42\x07\x32\x05\x18\x80\x80\x80\x04\x12\x64\n\rhash_function\x18\x03 \x01(\x0e\x32\x43.envoy.config.cluster.v4alpha.Cluster.RingHashLbConfig.HashFunctionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x43\n\x11maximum_ring_size\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\n\xfa\x42\x07\x32\x05\x18\x80\x80\x80\x04\".\n\x0cHashFunction\x12\x0b\n\x07XX_HASH\x10\x00\x12\x11\n\rMURMUR_HASH_2\x10\x01:7\x9a\xc5\x88\x1e\x32\n0envoy.config.cluster.v3.Cluster.RingHashLbConfigJ\x04\x08\x02\x10\x03\x1ay\n\x0eMaglevLbConfig\x12\x30\n\ntable_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value:5\x9a\xc5\x88\x1e\x30\n.envoy.config.cluster.v3.Cluster.MaglevLbConfig\x1aj\n\x13OriginalDstLbConfig\x12\x17\n\x0fuse_http_header\x18\x01 \x01(\x08::\x9a\xc5\x88\x1e\x35\n3envoy.config.cluster.v3.Cluster.OriginalDstLbConfig\x1a\xa8\t\n\x0e\x43ommonLbConfig\x12\x37\n\x17healthy_panic_threshold\x18\x01 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x66\n\x14zone_aware_lb_config\x18\x02 \x01(\x0b\x32\x46.envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.ZoneAwareLbConfigH\x00\x12t\n\x1blocality_weighted_lb_config\x18\x03 \x01(\x0b\x32M.envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.LocalityWeightedLbConfigH\x00\x12\x36\n\x13update_merge_window\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\'\n\x1fignore_new_hosts_until_first_hc\x18\x05 \x01(\x08\x12,\n$close_connections_on_host_set_change\x18\x06 \x01(\x08\x12t\n\x1c\x63onsistent_hashing_lb_config\x18\x07 \x01(\x0b\x32N.envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.ConsistentHashingLbConfig\x1a\xe4\x01\n\x11ZoneAwareLbConfig\x12/\n\x0frouting_enabled\x18\x01 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x36\n\x10min_cluster_size\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1d\n\x15\x66\x61il_traffic_on_panic\x18\x03 \x01(\x08:G\x9a\xc5\x88\x1e\x42\n@envoy.config.cluster.v3.Cluster.CommonLbConfig.ZoneAwareLbConfig\x1aj\n\x18LocalityWeightedLbConfig:N\x9a\xc5\x88\x1eI\nGenvoy.config.cluster.v3.Cluster.CommonLbConfig.LocalityWeightedLbConfig\x1a\xd2\x01\n\x19\x43onsistentHashingLbConfig\x12 \n\x18use_hostname_for_hashing\x18\x01 \x01(\x08\x12\x42\n\x13hash_balance_factor\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(d:O\x9a\xc5\x88\x1eJ\nHenvoy.config.cluster.v3.Cluster.CommonLbConfig.ConsistentHashingLbConfig:5\x9a\xc5\x88\x1e\x30\n.envoy.config.cluster.v3.Cluster.CommonLbConfigB\x1b\n\x19locality_config_specifier\x1a\xc2\x01\n\x0bRefreshRate\x12@\n\rbase_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xfa\x42\x0b\xaa\x01\x08\x08\x01*\x04\x10\xc0\x84=\x12=\n\x0cmax_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06*\x04\x10\xc0\x84=:2\x9a\xc5\x88\x1e-\n+envoy.config.cluster.v3.Cluster.RefreshRate\x1a\x85\x02\n\x10PreconnectPolicy\x12\\\n\x1dper_upstream_preconnect_ratio\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\x08@)\x00\x00\x00\x00\x00\x00\xf0?\x12Z\n\x1bpredictive_preconnect_ratio\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\x08@)\x00\x00\x00\x00\x00\x00\xf0?:7\x9a\xc5\x88\x1e\x32\n0envoy.config.cluster.v3.Cluster.PreconnectPolicy\x1aZ\n\"TypedExtensionProtocolOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\"W\n\rDiscoveryType\x12\n\n\x06STATIC\x10\x00\x12\x0e\n\nSTRICT_DNS\x10\x01\x12\x0f\n\x0bLOGICAL_DNS\x10\x02\x12\x07\n\x03\x45\x44S\x10\x03\x12\x10\n\x0cORIGINAL_DST\x10\x04\"\xa4\x01\n\x08LbPolicy\x12\x0f\n\x0bROUND_ROBIN\x10\x00\x12\x11\n\rLEAST_REQUEST\x10\x01\x12\r\n\tRING_HASH\x10\x02\x12\n\n\x06RANDOM\x10\x03\x12\n\n\x06MAGLEV\x10\x05\x12\x14\n\x10\x43LUSTER_PROVIDED\x10\x06\x12 \n\x1cLOAD_BALANCING_POLICY_CONFIG\x10\x07\"\x04\x08\x04\x10\x04*\x0fORIGINAL_DST_LB\"5\n\x0f\x44nsLookupFamily\x12\x08\n\x04\x41UTO\x10\x00\x12\x0b\n\x07V4_ONLY\x10\x01\x12\x0b\n\x07V6_ONLY\x10\x02\"T\n\x18\x43lusterProtocolSelection\x12\x1b\n\x17USE_CONFIGURED_PROTOCOL\x10\x00\x12\x1b\n\x17USE_DOWNSTREAM_PROTOCOL\x10\x01:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.config.cluster.v3.ClusterB\x18\n\x16\x63luster_discovery_typeB\x0b\n\tlb_configJ\x04\x08\x0c\x10\rJ\x04\x08\x0f\x10\x10J\x04\x08\x07\x10\x08J\x04\x08\x0b\x10\x0cJ\x04\x08#\x10$J\x04\x08.\x10/J\x04\x08\x1d\x10\x1eJ\x04\x08\r\x10\x0eJ\x04\x08\x0e\x10\x0fJ\x04\x08\x1a\x10\x1bJ\x04\x08/\x10\x30R\x05hostsR\x0btls_contextR\x1a\x65xtension_protocol_optionsR\x1eupstream_http_protocol_optionsR\x1c\x63ommon_http_protocol_optionsR\x15http_protocol_optionsR\x16http2_protocol_optionsR\x12protocol_selectionR\x15track_timeout_budgets\"\xa3\x02\n\x13LoadBalancingPolicy\x12J\n\x08policies\x18\x01 \x03(\x0b\x32\x38.envoy.config.cluster.v4alpha.LoadBalancingPolicy.Policy\x1a\x8b\x01\n\x06Policy\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any:9\x9a\xc5\x88\x1e\x34\n2envoy.config.cluster.v3.LoadBalancingPolicy.PolicyJ\x04\x08\x02\x10\x03R\x06\x63onfig:2\x9a\xc5\x88\x1e-\n+envoy.config.cluster.v3.LoadBalancingPolicy\"\x83\x01\n\x12UpstreamBindConfig\x12:\n\x0esource_address\x18\x01 \x01(\x0b\x32\".envoy.config.core.v4alpha.Address:1\x9a\xc5\x88\x1e,\n*envoy.config.cluster.v3.UpstreamBindConfig\"\x95\x01\n\x19UpstreamConnectionOptions\x12>\n\rtcp_keepalive\x18\x01 \x01(\x0b\x32\'.envoy.config.core.v4alpha.TcpKeepalive:8\x9a\xc5\x88\x1e\x33\n1envoy.config.cluster.v3.UpstreamConnectionOptions\"~\n\x11TrackClusterStats\x12\x17\n\x0ftimeout_budgets\x18\x01 \x01(\x08\x12\x1e\n\x16request_response_sizes\x18\x02 \x01(\x08:0\x9a\xc5\x88\x1e+\n)envoy.config.cluster.v3.TrackClusterStatsBD\n*io.envoyproxy.envoy.config.cluster.v4alphaB\x0c\x43lusterProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_cluster_dot_v4alpha_dot_circuit__breaker__pb2.DESCRIPTOR,envoy_dot_config_dot_cluster_dot_v4alpha_dot_filter__pb2.DESCRIPTOR,envoy_dot_config_dot_cluster_dot_v4alpha_dot_outlier__detection__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_health__check__pb2.DESCRIPTOR,envoy_dot_config_dot_endpoint_dot_v3_dot_endpoint__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,xds_dot_core_dot_v3_dot_collection__entry__pb2.DESCRIPTOR,udpa_dot_annotations_dot_security__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR_LBSUBSETSELECTORFALLBACKPOLICY = _descriptor.EnumDescriptor(
  name='LbSubsetSelectorFallbackPolicy',
  full_name='envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.LbSubsetSelector.LbSubsetSelectorFallbackPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_DEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_FALLBACK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANY_ENDPOINT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_SUBSET', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KEYS_SUBSET', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4944,
  serialized_end=5065,
)
_sym_db.RegisterEnumDescriptor(_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR_LBSUBSETSELECTORFALLBACKPOLICY)

_CLUSTER_LBSUBSETCONFIG_LBSUBSETFALLBACKPOLICY = _descriptor.EnumDescriptor(
  name='LbSubsetFallbackPolicy',
  full_name='envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.LbSubsetFallbackPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_FALLBACK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANY_ENDPOINT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_SUBSET', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5139,
  serialized_end=5218,
)
_sym_db.RegisterEnumDescriptor(_CLUSTER_LBSUBSETCONFIG_LBSUBSETFALLBACKPOLICY)

_CLUSTER_RINGHASHLBCONFIG_HASHFUNCTION = _descriptor.EnumDescriptor(
  name='HashFunction',
  full_name='envoy.config.cluster.v4alpha.Cluster.RingHashLbConfig.HashFunction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='XX_HASH', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MURMUR_HASH_2', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5754,
  serialized_end=5800,
)
_sym_db.RegisterEnumDescriptor(_CLUSTER_RINGHASHLBCONFIG_HASHFUNCTION)

_CLUSTER_DISCOVERYTYPE = _descriptor.EnumDescriptor(
  name='DiscoveryType',
  full_name='envoy.config.cluster.v4alpha.Cluster.DiscoveryType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATIC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRICT_DNS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGICAL_DNS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EDS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORIGINAL_DST', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7844,
  serialized_end=7931,
)
_sym_db.RegisterEnumDescriptor(_CLUSTER_DISCOVERYTYPE)

_CLUSTER_LBPOLICY = _descriptor.EnumDescriptor(
  name='LbPolicy',
  full_name='envoy.config.cluster.v4alpha.Cluster.LbPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ROUND_ROBIN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEAST_REQUEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RING_HASH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RANDOM', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAGLEV', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_PROVIDED', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOAD_BALANCING_POLICY_CONFIG', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7934,
  serialized_end=8098,
)
_sym_db.RegisterEnumDescriptor(_CLUSTER_LBPOLICY)

_CLUSTER_DNSLOOKUPFAMILY = _descriptor.EnumDescriptor(
  name='DnsLookupFamily',
  full_name='envoy.config.cluster.v4alpha.Cluster.DnsLookupFamily',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='V4_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='V6_ONLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8100,
  serialized_end=8153,
)
_sym_db.RegisterEnumDescriptor(_CLUSTER_DNSLOOKUPFAMILY)

_CLUSTER_CLUSTERPROTOCOLSELECTION = _descriptor.EnumDescriptor(
  name='ClusterProtocolSelection',
  full_name='envoy.config.cluster.v4alpha.Cluster.ClusterProtocolSelection',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='USE_CONFIGURED_PROTOCOL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USE_DOWNSTREAM_PROTOCOL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8155,
  serialized_end=8239,
)
_sym_db.RegisterEnumDescriptor(_CLUSTER_CLUSTERPROTOCOLSELECTION)


_CLUSTERCOLLECTION = _descriptor.Descriptor(
  name='ClusterCollection',
  full_name='envoy.config.cluster.v4alpha.ClusterCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='envoy.config.cluster.v4alpha.ClusterCollection.entries', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.config.cluster.v3.ClusterCollection',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=791,
  serialized_end=907,
)


_CLUSTER_TRANSPORTSOCKETMATCH = _descriptor.Descriptor(
  name='TransportSocketMatch',
  full_name='envoy.config.cluster.v4alpha.Cluster.TransportSocketMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.cluster.v4alpha.Cluster.TransportSocketMatch.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match', full_name='envoy.config.cluster.v4alpha.Cluster.TransportSocketMatch.match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_socket', full_name='envoy.config.cluster.v4alpha.Cluster.TransportSocketMatch.transport_socket', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0366\n4envoy.config.cluster.v3.Cluster.TransportSocketMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3799,
  serialized_end=4015,
)

_CLUSTER_CUSTOMCLUSTERTYPE = _descriptor.Descriptor(
  name='CustomClusterType',
  full_name='envoy.config.cluster.v4alpha.Cluster.CustomClusterType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.cluster.v4alpha.Cluster.CustomClusterType.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.cluster.v4alpha.Cluster.CustomClusterType.typed_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0363\n1envoy.config.cluster.v3.Cluster.CustomClusterType',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4018,
  serialized_end=4162,
)

_CLUSTER_EDSCLUSTERCONFIG = _descriptor.Descriptor(
  name='EdsClusterConfig',
  full_name='envoy.config.cluster.v4alpha.Cluster.EdsClusterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eds_config', full_name='envoy.config.cluster.v4alpha.Cluster.EdsClusterConfig.eds_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_name', full_name='envoy.config.cluster.v4alpha.Cluster.EdsClusterConfig.service_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0362\n0envoy.config.cluster.v3.Cluster.EdsClusterConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4165,
  serialized_end=4323,
)

_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR = _descriptor.Descriptor(
  name='LbSubsetSelector',
  full_name='envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.LbSubsetSelector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.LbSubsetSelector.keys', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='single_host_per_subset', full_name='envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.LbSubsetSelector.single_host_per_subset', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fallback_policy', full_name='envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.LbSubsetSelector.fallback_policy', index=2,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fallback_keys_subset', full_name='envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.LbSubsetSelector.fallback_keys_subset', index=3,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR_LBSUBSETSELECTORFALLBACKPOLICY,
  ],
  serialized_options=b'\232\305\210\036A\n?envoy.config.cluster.v3.Cluster.LbSubsetConfig.LbSubsetSelector',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4710,
  serialized_end=5137,
)

_CLUSTER_LBSUBSETCONFIG = _descriptor.Descriptor(
  name='LbSubsetConfig',
  full_name='envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fallback_policy', full_name='envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.fallback_policy', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_subset', full_name='envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.default_subset', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subset_selectors', full_name='envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.subset_selectors', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locality_weight_aware', full_name='envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.locality_weight_aware', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale_locality_weight', full_name='envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.scale_locality_weight', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='panic_mode_any', full_name='envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.panic_mode_any', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_as_any', full_name='envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.list_as_any', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR, ],
  enum_types=[
    _CLUSTER_LBSUBSETCONFIG_LBSUBSETFALLBACKPOLICY,
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.config.cluster.v3.Cluster.LbSubsetConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4326,
  serialized_end=5273,
)

_CLUSTER_LEASTREQUESTLBCONFIG = _descriptor.Descriptor(
  name='LeastRequestLbConfig',
  full_name='envoy.config.cluster.v4alpha.Cluster.LeastRequestLbConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice_count', full_name='envoy.config.cluster.v4alpha.Cluster.LeastRequestLbConfig.choice_count', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_request_bias', full_name='envoy.config.cluster.v4alpha.Cluster.LeastRequestLbConfig.active_request_bias', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0366\n4envoy.config.cluster.v3.Cluster.LeastRequestLbConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5276,
  serialized_end=5491,
)

_CLUSTER_RINGHASHLBCONFIG = _descriptor.Descriptor(
  name='RingHashLbConfig',
  full_name='envoy.config.cluster.v4alpha.Cluster.RingHashLbConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='minimum_ring_size', full_name='envoy.config.cluster.v4alpha.Cluster.RingHashLbConfig.minimum_ring_size', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\0072\005\030\200\200\200\004', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash_function', full_name='envoy.config.cluster.v4alpha.Cluster.RingHashLbConfig.hash_function', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum_ring_size', full_name='envoy.config.cluster.v4alpha.Cluster.RingHashLbConfig.maximum_ring_size', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\0072\005\030\200\200\200\004', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLUSTER_RINGHASHLBCONFIG_HASHFUNCTION,
  ],
  serialized_options=b'\232\305\210\0362\n0envoy.config.cluster.v3.Cluster.RingHashLbConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5494,
  serialized_end=5863,
)

_CLUSTER_MAGLEVLBCONFIG = _descriptor.Descriptor(
  name='MaglevLbConfig',
  full_name='envoy.config.cluster.v4alpha.Cluster.MaglevLbConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_size', full_name='envoy.config.cluster.v4alpha.Cluster.MaglevLbConfig.table_size', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.config.cluster.v3.Cluster.MaglevLbConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5865,
  serialized_end=5986,
)

_CLUSTER_ORIGINALDSTLBCONFIG = _descriptor.Descriptor(
  name='OriginalDstLbConfig',
  full_name='envoy.config.cluster.v4alpha.Cluster.OriginalDstLbConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_http_header', full_name='envoy.config.cluster.v4alpha.Cluster.OriginalDstLbConfig.use_http_header', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0365\n3envoy.config.cluster.v3.Cluster.OriginalDstLbConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5988,
  serialized_end=6094,
)

_CLUSTER_COMMONLBCONFIG_ZONEAWARELBCONFIG = _descriptor.Descriptor(
  name='ZoneAwareLbConfig',
  full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.ZoneAwareLbConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='routing_enabled', full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.ZoneAwareLbConfig.routing_enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_cluster_size', full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.ZoneAwareLbConfig.min_cluster_size', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fail_traffic_on_panic', full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.ZoneAwareLbConfig.fail_traffic_on_panic', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036B\n@envoy.config.cluster.v3.Cluster.CommonLbConfig.ZoneAwareLbConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6656,
  serialized_end=6884,
)

_CLUSTER_COMMONLBCONFIG_LOCALITYWEIGHTEDLBCONFIG = _descriptor.Descriptor(
  name='LocalityWeightedLbConfig',
  full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.LocalityWeightedLbConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036I\nGenvoy.config.cluster.v3.Cluster.CommonLbConfig.LocalityWeightedLbConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6886,
  serialized_end=6992,
)

_CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG = _descriptor.Descriptor(
  name='ConsistentHashingLbConfig',
  full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.ConsistentHashingLbConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_hostname_for_hashing', full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.ConsistentHashingLbConfig.use_hostname_for_hashing', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash_balance_factor', full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.ConsistentHashingLbConfig.hash_balance_factor', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036J\nHenvoy.config.cluster.v3.Cluster.CommonLbConfig.ConsistentHashingLbConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6995,
  serialized_end=7205,
)

_CLUSTER_COMMONLBCONFIG = _descriptor.Descriptor(
  name='CommonLbConfig',
  full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='healthy_panic_threshold', full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.healthy_panic_threshold', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_aware_lb_config', full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.zone_aware_lb_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locality_weighted_lb_config', full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.locality_weighted_lb_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_merge_window', full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.update_merge_window', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_new_hosts_until_first_hc', full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.ignore_new_hosts_until_first_hc', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close_connections_on_host_set_change', full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.close_connections_on_host_set_change', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consistent_hashing_lb_config', full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.consistent_hashing_lb_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTER_COMMONLBCONFIG_ZONEAWARELBCONFIG, _CLUSTER_COMMONLBCONFIG_LOCALITYWEIGHTEDLBCONFIG, _CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.config.cluster.v3.Cluster.CommonLbConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='locality_config_specifier', full_name='envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.locality_config_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6097,
  serialized_end=7289,
)

_CLUSTER_REFRESHRATE = _descriptor.Descriptor(
  name='RefreshRate',
  full_name='envoy.config.cluster.v4alpha.Cluster.RefreshRate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_interval', full_name='envoy.config.cluster.v4alpha.Cluster.RefreshRate.base_interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\252\001\010\010\001*\004\020\300\204=', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_interval', full_name='envoy.config.cluster.v4alpha.Cluster.RefreshRate.max_interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\t\252\001\006*\004\020\300\204=', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.config.cluster.v3.Cluster.RefreshRate',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7292,
  serialized_end=7486,
)

_CLUSTER_PRECONNECTPOLICY = _descriptor.Descriptor(
  name='PreconnectPolicy',
  full_name='envoy.config.cluster.v4alpha.Cluster.PreconnectPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='per_upstream_preconnect_ratio', full_name='envoy.config.cluster.v4alpha.Cluster.PreconnectPolicy.per_upstream_preconnect_ratio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\024\022\022\031\000\000\000\000\000\000\010@)\000\000\000\000\000\000\360?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predictive_preconnect_ratio', full_name='envoy.config.cluster.v4alpha.Cluster.PreconnectPolicy.predictive_preconnect_ratio', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\024\022\022\031\000\000\000\000\000\000\010@)\000\000\000\000\000\000\360?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0362\n0envoy.config.cluster.v3.Cluster.PreconnectPolicy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7489,
  serialized_end=7750,
)

_CLUSTER_TYPEDEXTENSIONPROTOCOLOPTIONSENTRY = _descriptor.Descriptor(
  name='TypedExtensionProtocolOptionsEntry',
  full_name='envoy.config.cluster.v4alpha.Cluster.TypedExtensionProtocolOptionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.cluster.v4alpha.Cluster.TypedExtensionProtocolOptionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.cluster.v4alpha.Cluster.TypedExtensionProtocolOptionsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7752,
  serialized_end=7842,
)

_CLUSTER = _descriptor.Descriptor(
  name='Cluster',
  full_name='envoy.config.cluster.v4alpha.Cluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transport_socket_matches', full_name='envoy.config.cluster.v4alpha.Cluster.transport_socket_matches', index=0,
      number=43, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.cluster.v4alpha.Cluster.name', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alt_stat_name', full_name='envoy.config.cluster.v4alpha.Cluster.alt_stat_name', index=2,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='envoy.config.cluster.v4alpha.Cluster.type', index=3,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_type', full_name='envoy.config.cluster.v4alpha.Cluster.cluster_type', index=4,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eds_cluster_config', full_name='envoy.config.cluster.v4alpha.Cluster.eds_cluster_config', index=5,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_timeout', full_name='envoy.config.cluster.v4alpha.Cluster.connect_timeout', index=6,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='per_connection_buffer_limit_bytes', full_name='envoy.config.cluster.v4alpha.Cluster.per_connection_buffer_limit_bytes', index=7,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\223\267*\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lb_policy', full_name='envoy.config.cluster.v4alpha.Cluster.lb_policy', index=8,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\202\001\004\020\001 \007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_assignment', full_name='envoy.config.cluster.v4alpha.Cluster.load_assignment', index=9,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_checks', full_name='envoy.config.cluster.v4alpha.Cluster.health_checks', index=10,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_requests_per_connection', full_name='envoy.config.cluster.v4alpha.Cluster.max_requests_per_connection', index=11,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='circuit_breakers', full_name='envoy.config.cluster.v4alpha.Cluster.circuit_breakers', index=12,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_extension_protocol_options', full_name='envoy.config.cluster.v4alpha.Cluster.typed_extension_protocol_options', index=13,
      number=36, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_refresh_rate', full_name='envoy.config.cluster.v4alpha.Cluster.dns_refresh_rate', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\t\252\001\006*\004\020\300\204=', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_failure_refresh_rate', full_name='envoy.config.cluster.v4alpha.Cluster.dns_failure_refresh_rate', index=15,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='respect_dns_ttl', full_name='envoy.config.cluster.v4alpha.Cluster.respect_dns_ttl', index=16,
      number=39, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_lookup_family', full_name='envoy.config.cluster.v4alpha.Cluster.dns_lookup_family', index=17,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_resolvers', full_name='envoy.config.cluster.v4alpha.Cluster.dns_resolvers', index=18,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_tcp_for_dns_lookups', full_name='envoy.config.cluster.v4alpha.Cluster.use_tcp_for_dns_lookups', index=19,
      number=45, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outlier_detection', full_name='envoy.config.cluster.v4alpha.Cluster.outlier_detection', index=20,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cleanup_interval', full_name='envoy.config.cluster.v4alpha.Cluster.cleanup_interval', index=21,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_bind_config', full_name='envoy.config.cluster.v4alpha.Cluster.upstream_bind_config', index=22,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lb_subset_config', full_name='envoy.config.cluster.v4alpha.Cluster.lb_subset_config', index=23,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ring_hash_lb_config', full_name='envoy.config.cluster.v4alpha.Cluster.ring_hash_lb_config', index=24,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maglev_lb_config', full_name='envoy.config.cluster.v4alpha.Cluster.maglev_lb_config', index=25,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='original_dst_lb_config', full_name='envoy.config.cluster.v4alpha.Cluster.original_dst_lb_config', index=26,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='least_request_lb_config', full_name='envoy.config.cluster.v4alpha.Cluster.least_request_lb_config', index=27,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='common_lb_config', full_name='envoy.config.cluster.v4alpha.Cluster.common_lb_config', index=28,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_socket', full_name='envoy.config.cluster.v4alpha.Cluster.transport_socket', index=29,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.config.cluster.v4alpha.Cluster.metadata', index=30,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_connection_options', full_name='envoy.config.cluster.v4alpha.Cluster.upstream_connection_options', index=31,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close_connections_on_host_health_failure', full_name='envoy.config.cluster.v4alpha.Cluster.close_connections_on_host_health_failure', index=32,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_health_on_host_removal', full_name='envoy.config.cluster.v4alpha.Cluster.ignore_health_on_host_removal', index=33,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='envoy.config.cluster.v4alpha.Cluster.filters', index=34,
      number=40, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_balancing_policy', full_name='envoy.config.cluster.v4alpha.Cluster.load_balancing_policy', index=35,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lrs_server', full_name='envoy.config.cluster.v4alpha.Cluster.lrs_server', index=36,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_config', full_name='envoy.config.cluster.v4alpha.Cluster.upstream_config', index=37,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='track_cluster_stats', full_name='envoy.config.cluster.v4alpha.Cluster.track_cluster_stats', index=38,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preconnect_policy', full_name='envoy.config.cluster.v4alpha.Cluster.preconnect_policy', index=39,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_pool_per_downstream_connection', full_name='envoy.config.cluster.v4alpha.Cluster.connection_pool_per_downstream_connection', index=40,
      number=51, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTER_TRANSPORTSOCKETMATCH, _CLUSTER_CUSTOMCLUSTERTYPE, _CLUSTER_EDSCLUSTERCONFIG, _CLUSTER_LBSUBSETCONFIG, _CLUSTER_LEASTREQUESTLBCONFIG, _CLUSTER_RINGHASHLBCONFIG, _CLUSTER_MAGLEVLBCONFIG, _CLUSTER_ORIGINALDSTLBCONFIG, _CLUSTER_COMMONLBCONFIG, _CLUSTER_REFRESHRATE, _CLUSTER_PRECONNECTPOLICY, _CLUSTER_TYPEDEXTENSIONPROTOCOLOPTIONSENTRY, ],
  enum_types=[
    _CLUSTER_DISCOVERYTYPE,
    _CLUSTER_LBPOLICY,
    _CLUSTER_DNSLOOKUPFAMILY,
    _CLUSTER_CLUSTERPROTOCOLSELECTION,
  ],
  serialized_options=b'\232\305\210\036!\n\037envoy.config.cluster.v3.Cluster',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='cluster_discovery_type', full_name='envoy.config.cluster.v4alpha.Cluster.cluster_discovery_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='lb_config', full_name='envoy.config.cluster.v4alpha.Cluster.lb_config',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=910,
  serialized_end=8584,
)


_LOADBALANCINGPOLICY_POLICY = _descriptor.Descriptor(
  name='Policy',
  full_name='envoy.config.cluster.v4alpha.LoadBalancingPolicy.Policy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.cluster.v4alpha.LoadBalancingPolicy.Policy.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.cluster.v4alpha.LoadBalancingPolicy.Policy.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.config.cluster.v3.LoadBalancingPolicy.Policy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8687,
  serialized_end=8826,
)

_LOADBALANCINGPOLICY = _descriptor.Descriptor(
  name='LoadBalancingPolicy',
  full_name='envoy.config.cluster.v4alpha.LoadBalancingPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='policies', full_name='envoy.config.cluster.v4alpha.LoadBalancingPolicy.policies', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LOADBALANCINGPOLICY_POLICY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.config.cluster.v3.LoadBalancingPolicy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8587,
  serialized_end=8878,
)


_UPSTREAMBINDCONFIG = _descriptor.Descriptor(
  name='UpstreamBindConfig',
  full_name='envoy.config.cluster.v4alpha.UpstreamBindConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_address', full_name='envoy.config.cluster.v4alpha.UpstreamBindConfig.source_address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.config.cluster.v3.UpstreamBindConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8881,
  serialized_end=9012,
)


_UPSTREAMCONNECTIONOPTIONS = _descriptor.Descriptor(
  name='UpstreamConnectionOptions',
  full_name='envoy.config.cluster.v4alpha.UpstreamConnectionOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tcp_keepalive', full_name='envoy.config.cluster.v4alpha.UpstreamConnectionOptions.tcp_keepalive', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0363\n1envoy.config.cluster.v3.UpstreamConnectionOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9015,
  serialized_end=9164,
)


_TRACKCLUSTERSTATS = _descriptor.Descriptor(
  name='TrackClusterStats',
  full_name='envoy.config.cluster.v4alpha.TrackClusterStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeout_budgets', full_name='envoy.config.cluster.v4alpha.TrackClusterStats.timeout_budgets', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_response_sizes', full_name='envoy.config.cluster.v4alpha.TrackClusterStats.request_response_sizes', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.config.cluster.v3.TrackClusterStats',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9166,
  serialized_end=9292,
)

_CLUSTERCOLLECTION.fields_by_name['entries'].message_type = xds_dot_core_dot_v3_dot_collection__entry__pb2._COLLECTIONENTRY
_CLUSTER_TRANSPORTSOCKETMATCH.fields_by_name['match'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_CLUSTER_TRANSPORTSOCKETMATCH.fields_by_name['transport_socket'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._TRANSPORTSOCKET
_CLUSTER_TRANSPORTSOCKETMATCH.containing_type = _CLUSTER
_CLUSTER_CUSTOMCLUSTERTYPE.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CLUSTER_CUSTOMCLUSTERTYPE.containing_type = _CLUSTER
_CLUSTER_EDSCLUSTERCONFIG.fields_by_name['eds_config'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._CONFIGSOURCE
_CLUSTER_EDSCLUSTERCONFIG.containing_type = _CLUSTER
_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR.fields_by_name['fallback_policy'].enum_type = _CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR_LBSUBSETSELECTORFALLBACKPOLICY
_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR.containing_type = _CLUSTER_LBSUBSETCONFIG
_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR_LBSUBSETSELECTORFALLBACKPOLICY.containing_type = _CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR
_CLUSTER_LBSUBSETCONFIG.fields_by_name['fallback_policy'].enum_type = _CLUSTER_LBSUBSETCONFIG_LBSUBSETFALLBACKPOLICY
_CLUSTER_LBSUBSETCONFIG.fields_by_name['default_subset'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_CLUSTER_LBSUBSETCONFIG.fields_by_name['subset_selectors'].message_type = _CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR
_CLUSTER_LBSUBSETCONFIG.containing_type = _CLUSTER
_CLUSTER_LBSUBSETCONFIG_LBSUBSETFALLBACKPOLICY.containing_type = _CLUSTER_LBSUBSETCONFIG
_CLUSTER_LEASTREQUESTLBCONFIG.fields_by_name['choice_count'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CLUSTER_LEASTREQUESTLBCONFIG.fields_by_name['active_request_bias'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._RUNTIMEDOUBLE
_CLUSTER_LEASTREQUESTLBCONFIG.containing_type = _CLUSTER
_CLUSTER_RINGHASHLBCONFIG.fields_by_name['minimum_ring_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_CLUSTER_RINGHASHLBCONFIG.fields_by_name['hash_function'].enum_type = _CLUSTER_RINGHASHLBCONFIG_HASHFUNCTION
_CLUSTER_RINGHASHLBCONFIG.fields_by_name['maximum_ring_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_CLUSTER_RINGHASHLBCONFIG.containing_type = _CLUSTER
_CLUSTER_RINGHASHLBCONFIG_HASHFUNCTION.containing_type = _CLUSTER_RINGHASHLBCONFIG
_CLUSTER_MAGLEVLBCONFIG.fields_by_name['table_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_CLUSTER_MAGLEVLBCONFIG.containing_type = _CLUSTER
_CLUSTER_ORIGINALDSTLBCONFIG.containing_type = _CLUSTER
_CLUSTER_COMMONLBCONFIG_ZONEAWARELBCONFIG.fields_by_name['routing_enabled'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._PERCENT
_CLUSTER_COMMONLBCONFIG_ZONEAWARELBCONFIG.fields_by_name['min_cluster_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_CLUSTER_COMMONLBCONFIG_ZONEAWARELBCONFIG.containing_type = _CLUSTER_COMMONLBCONFIG
_CLUSTER_COMMONLBCONFIG_LOCALITYWEIGHTEDLBCONFIG.containing_type = _CLUSTER_COMMONLBCONFIG
_CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG.fields_by_name['hash_balance_factor'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG.containing_type = _CLUSTER_COMMONLBCONFIG
_CLUSTER_COMMONLBCONFIG.fields_by_name['healthy_panic_threshold'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._PERCENT
_CLUSTER_COMMONLBCONFIG.fields_by_name['zone_aware_lb_config'].message_type = _CLUSTER_COMMONLBCONFIG_ZONEAWARELBCONFIG
_CLUSTER_COMMONLBCONFIG.fields_by_name['locality_weighted_lb_config'].message_type = _CLUSTER_COMMONLBCONFIG_LOCALITYWEIGHTEDLBCONFIG
_CLUSTER_COMMONLBCONFIG.fields_by_name['update_merge_window'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CLUSTER_COMMONLBCONFIG.fields_by_name['consistent_hashing_lb_config'].message_type = _CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG
_CLUSTER_COMMONLBCONFIG.containing_type = _CLUSTER
_CLUSTER_COMMONLBCONFIG.oneofs_by_name['locality_config_specifier'].fields.append(
  _CLUSTER_COMMONLBCONFIG.fields_by_name['zone_aware_lb_config'])
_CLUSTER_COMMONLBCONFIG.fields_by_name['zone_aware_lb_config'].containing_oneof = _CLUSTER_COMMONLBCONFIG.oneofs_by_name['locality_config_specifier']
_CLUSTER_COMMONLBCONFIG.oneofs_by_name['locality_config_specifier'].fields.append(
  _CLUSTER_COMMONLBCONFIG.fields_by_name['locality_weighted_lb_config'])
_CLUSTER_COMMONLBCONFIG.fields_by_name['locality_weighted_lb_config'].containing_oneof = _CLUSTER_COMMONLBCONFIG.oneofs_by_name['locality_config_specifier']
_CLUSTER_REFRESHRATE.fields_by_name['base_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CLUSTER_REFRESHRATE.fields_by_name['max_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CLUSTER_REFRESHRATE.containing_type = _CLUSTER
_CLUSTER_PRECONNECTPOLICY.fields_by_name['per_upstream_preconnect_ratio'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_CLUSTER_PRECONNECTPOLICY.fields_by_name['predictive_preconnect_ratio'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_CLUSTER_PRECONNECTPOLICY.containing_type = _CLUSTER
_CLUSTER_TYPEDEXTENSIONPROTOCOLOPTIONSENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CLUSTER_TYPEDEXTENSIONPROTOCOLOPTIONSENTRY.containing_type = _CLUSTER
_CLUSTER.fields_by_name['transport_socket_matches'].message_type = _CLUSTER_TRANSPORTSOCKETMATCH
_CLUSTER.fields_by_name['type'].enum_type = _CLUSTER_DISCOVERYTYPE
_CLUSTER.fields_by_name['cluster_type'].message_type = _CLUSTER_CUSTOMCLUSTERTYPE
_CLUSTER.fields_by_name['eds_cluster_config'].message_type = _CLUSTER_EDSCLUSTERCONFIG
_CLUSTER.fields_by_name['connect_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CLUSTER.fields_by_name['per_connection_buffer_limit_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CLUSTER.fields_by_name['lb_policy'].enum_type = _CLUSTER_LBPOLICY
_CLUSTER.fields_by_name['load_assignment'].message_type = envoy_dot_config_dot_endpoint_dot_v3_dot_endpoint__pb2._CLUSTERLOADASSIGNMENT
_CLUSTER.fields_by_name['health_checks'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_health__check__pb2._HEALTHCHECK
_CLUSTER.fields_by_name['max_requests_per_connection'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CLUSTER.fields_by_name['circuit_breakers'].message_type = envoy_dot_config_dot_cluster_dot_v4alpha_dot_circuit__breaker__pb2._CIRCUITBREAKERS
_CLUSTER.fields_by_name['typed_extension_protocol_options'].message_type = _CLUSTER_TYPEDEXTENSIONPROTOCOLOPTIONSENTRY
_CLUSTER.fields_by_name['dns_refresh_rate'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CLUSTER.fields_by_name['dns_failure_refresh_rate'].message_type = _CLUSTER_REFRESHRATE
_CLUSTER.fields_by_name['dns_lookup_family'].enum_type = _CLUSTER_DNSLOOKUPFAMILY
_CLUSTER.fields_by_name['dns_resolvers'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2._ADDRESS
_CLUSTER.fields_by_name['outlier_detection'].message_type = envoy_dot_config_dot_cluster_dot_v4alpha_dot_outlier__detection__pb2._OUTLIERDETECTION
_CLUSTER.fields_by_name['cleanup_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CLUSTER.fields_by_name['upstream_bind_config'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2._BINDCONFIG
_CLUSTER.fields_by_name['lb_subset_config'].message_type = _CLUSTER_LBSUBSETCONFIG
_CLUSTER.fields_by_name['ring_hash_lb_config'].message_type = _CLUSTER_RINGHASHLBCONFIG
_CLUSTER.fields_by_name['maglev_lb_config'].message_type = _CLUSTER_MAGLEVLBCONFIG
_CLUSTER.fields_by_name['original_dst_lb_config'].message_type = _CLUSTER_ORIGINALDSTLBCONFIG
_CLUSTER.fields_by_name['least_request_lb_config'].message_type = _CLUSTER_LEASTREQUESTLBCONFIG
_CLUSTER.fields_by_name['common_lb_config'].message_type = _CLUSTER_COMMONLBCONFIG
_CLUSTER.fields_by_name['transport_socket'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._TRANSPORTSOCKET
_CLUSTER.fields_by_name['metadata'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._METADATA
_CLUSTER.fields_by_name['upstream_connection_options'].message_type = _UPSTREAMCONNECTIONOPTIONS
_CLUSTER.fields_by_name['filters'].message_type = envoy_dot_config_dot_cluster_dot_v4alpha_dot_filter__pb2._FILTER
_CLUSTER.fields_by_name['load_balancing_policy'].message_type = _LOADBALANCINGPOLICY
_CLUSTER.fields_by_name['lrs_server'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._CONFIGSOURCE
_CLUSTER.fields_by_name['upstream_config'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_CLUSTER.fields_by_name['track_cluster_stats'].message_type = _TRACKCLUSTERSTATS
_CLUSTER.fields_by_name['preconnect_policy'].message_type = _CLUSTER_PRECONNECTPOLICY
_CLUSTER_DISCOVERYTYPE.containing_type = _CLUSTER
_CLUSTER_LBPOLICY.containing_type = _CLUSTER
_CLUSTER_DNSLOOKUPFAMILY.containing_type = _CLUSTER
_CLUSTER_CLUSTERPROTOCOLSELECTION.containing_type = _CLUSTER
_CLUSTER.oneofs_by_name['cluster_discovery_type'].fields.append(
  _CLUSTER.fields_by_name['type'])
_CLUSTER.fields_by_name['type'].containing_oneof = _CLUSTER.oneofs_by_name['cluster_discovery_type']
_CLUSTER.oneofs_by_name['cluster_discovery_type'].fields.append(
  _CLUSTER.fields_by_name['cluster_type'])
_CLUSTER.fields_by_name['cluster_type'].containing_oneof = _CLUSTER.oneofs_by_name['cluster_discovery_type']
_CLUSTER.oneofs_by_name['lb_config'].fields.append(
  _CLUSTER.fields_by_name['ring_hash_lb_config'])
_CLUSTER.fields_by_name['ring_hash_lb_config'].containing_oneof = _CLUSTER.oneofs_by_name['lb_config']
_CLUSTER.oneofs_by_name['lb_config'].fields.append(
  _CLUSTER.fields_by_name['maglev_lb_config'])
_CLUSTER.fields_by_name['maglev_lb_config'].containing_oneof = _CLUSTER.oneofs_by_name['lb_config']
_CLUSTER.oneofs_by_name['lb_config'].fields.append(
  _CLUSTER.fields_by_name['original_dst_lb_config'])
_CLUSTER.fields_by_name['original_dst_lb_config'].containing_oneof = _CLUSTER.oneofs_by_name['lb_config']
_CLUSTER.oneofs_by_name['lb_config'].fields.append(
  _CLUSTER.fields_by_name['least_request_lb_config'])
_CLUSTER.fields_by_name['least_request_lb_config'].containing_oneof = _CLUSTER.oneofs_by_name['lb_config']
_LOADBALANCINGPOLICY_POLICY.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_LOADBALANCINGPOLICY_POLICY.containing_type = _LOADBALANCINGPOLICY
_LOADBALANCINGPOLICY.fields_by_name['policies'].message_type = _LOADBALANCINGPOLICY_POLICY
_UPSTREAMBINDCONFIG.fields_by_name['source_address'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2._ADDRESS
_UPSTREAMCONNECTIONOPTIONS.fields_by_name['tcp_keepalive'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2._TCPKEEPALIVE
DESCRIPTOR.message_types_by_name['ClusterCollection'] = _CLUSTERCOLLECTION
DESCRIPTOR.message_types_by_name['Cluster'] = _CLUSTER
DESCRIPTOR.message_types_by_name['LoadBalancingPolicy'] = _LOADBALANCINGPOLICY
DESCRIPTOR.message_types_by_name['UpstreamBindConfig'] = _UPSTREAMBINDCONFIG
DESCRIPTOR.message_types_by_name['UpstreamConnectionOptions'] = _UPSTREAMCONNECTIONOPTIONS
DESCRIPTOR.message_types_by_name['TrackClusterStats'] = _TRACKCLUSTERSTATS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClusterCollection = _reflection.GeneratedProtocolMessageType('ClusterCollection', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERCOLLECTION,
  '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.ClusterCollection)
  })
_sym_db.RegisterMessage(ClusterCollection)

Cluster = _reflection.GeneratedProtocolMessageType('Cluster', (_message.Message,), {

  'TransportSocketMatch' : _reflection.GeneratedProtocolMessageType('TransportSocketMatch', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTER_TRANSPORTSOCKETMATCH,
    '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.TransportSocketMatch)
    })
  ,

  'CustomClusterType' : _reflection.GeneratedProtocolMessageType('CustomClusterType', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTER_CUSTOMCLUSTERTYPE,
    '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.CustomClusterType)
    })
  ,

  'EdsClusterConfig' : _reflection.GeneratedProtocolMessageType('EdsClusterConfig', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTER_EDSCLUSTERCONFIG,
    '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.EdsClusterConfig)
    })
  ,

  'LbSubsetConfig' : _reflection.GeneratedProtocolMessageType('LbSubsetConfig', (_message.Message,), {

    'LbSubsetSelector' : _reflection.GeneratedProtocolMessageType('LbSubsetSelector', (_message.Message,), {
      'DESCRIPTOR' : _CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR,
      '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig.LbSubsetSelector)
      })
    ,
    'DESCRIPTOR' : _CLUSTER_LBSUBSETCONFIG,
    '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.LbSubsetConfig)
    })
  ,

  'LeastRequestLbConfig' : _reflection.GeneratedProtocolMessageType('LeastRequestLbConfig', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTER_LEASTREQUESTLBCONFIG,
    '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.LeastRequestLbConfig)
    })
  ,

  'RingHashLbConfig' : _reflection.GeneratedProtocolMessageType('RingHashLbConfig', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTER_RINGHASHLBCONFIG,
    '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.RingHashLbConfig)
    })
  ,

  'MaglevLbConfig' : _reflection.GeneratedProtocolMessageType('MaglevLbConfig', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTER_MAGLEVLBCONFIG,
    '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.MaglevLbConfig)
    })
  ,

  'OriginalDstLbConfig' : _reflection.GeneratedProtocolMessageType('OriginalDstLbConfig', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTER_ORIGINALDSTLBCONFIG,
    '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.OriginalDstLbConfig)
    })
  ,

  'CommonLbConfig' : _reflection.GeneratedProtocolMessageType('CommonLbConfig', (_message.Message,), {

    'ZoneAwareLbConfig' : _reflection.GeneratedProtocolMessageType('ZoneAwareLbConfig', (_message.Message,), {
      'DESCRIPTOR' : _CLUSTER_COMMONLBCONFIG_ZONEAWARELBCONFIG,
      '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.ZoneAwareLbConfig)
      })
    ,

    'LocalityWeightedLbConfig' : _reflection.GeneratedProtocolMessageType('LocalityWeightedLbConfig', (_message.Message,), {
      'DESCRIPTOR' : _CLUSTER_COMMONLBCONFIG_LOCALITYWEIGHTEDLBCONFIG,
      '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.LocalityWeightedLbConfig)
      })
    ,

    'ConsistentHashingLbConfig' : _reflection.GeneratedProtocolMessageType('ConsistentHashingLbConfig', (_message.Message,), {
      'DESCRIPTOR' : _CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG,
      '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.CommonLbConfig.ConsistentHashingLbConfig)
      })
    ,
    'DESCRIPTOR' : _CLUSTER_COMMONLBCONFIG,
    '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.CommonLbConfig)
    })
  ,

  'RefreshRate' : _reflection.GeneratedProtocolMessageType('RefreshRate', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTER_REFRESHRATE,
    '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.RefreshRate)
    })
  ,

  'PreconnectPolicy' : _reflection.GeneratedProtocolMessageType('PreconnectPolicy', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTER_PRECONNECTPOLICY,
    '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.PreconnectPolicy)
    })
  ,

  'TypedExtensionProtocolOptionsEntry' : _reflection.GeneratedProtocolMessageType('TypedExtensionProtocolOptionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTER_TYPEDEXTENSIONPROTOCOLOPTIONSENTRY,
    '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster.TypedExtensionProtocolOptionsEntry)
    })
  ,
  'DESCRIPTOR' : _CLUSTER,
  '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.Cluster)
  })
_sym_db.RegisterMessage(Cluster)
_sym_db.RegisterMessage(Cluster.TransportSocketMatch)
_sym_db.RegisterMessage(Cluster.CustomClusterType)
_sym_db.RegisterMessage(Cluster.EdsClusterConfig)
_sym_db.RegisterMessage(Cluster.LbSubsetConfig)
_sym_db.RegisterMessage(Cluster.LbSubsetConfig.LbSubsetSelector)
_sym_db.RegisterMessage(Cluster.LeastRequestLbConfig)
_sym_db.RegisterMessage(Cluster.RingHashLbConfig)
_sym_db.RegisterMessage(Cluster.MaglevLbConfig)
_sym_db.RegisterMessage(Cluster.OriginalDstLbConfig)
_sym_db.RegisterMessage(Cluster.CommonLbConfig)
_sym_db.RegisterMessage(Cluster.CommonLbConfig.ZoneAwareLbConfig)
_sym_db.RegisterMessage(Cluster.CommonLbConfig.LocalityWeightedLbConfig)
_sym_db.RegisterMessage(Cluster.CommonLbConfig.ConsistentHashingLbConfig)
_sym_db.RegisterMessage(Cluster.RefreshRate)
_sym_db.RegisterMessage(Cluster.PreconnectPolicy)
_sym_db.RegisterMessage(Cluster.TypedExtensionProtocolOptionsEntry)

LoadBalancingPolicy = _reflection.GeneratedProtocolMessageType('LoadBalancingPolicy', (_message.Message,), {

  'Policy' : _reflection.GeneratedProtocolMessageType('Policy', (_message.Message,), {
    'DESCRIPTOR' : _LOADBALANCINGPOLICY_POLICY,
    '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.LoadBalancingPolicy.Policy)
    })
  ,
  'DESCRIPTOR' : _LOADBALANCINGPOLICY,
  '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.LoadBalancingPolicy)
  })
_sym_db.RegisterMessage(LoadBalancingPolicy)
_sym_db.RegisterMessage(LoadBalancingPolicy.Policy)

UpstreamBindConfig = _reflection.GeneratedProtocolMessageType('UpstreamBindConfig', (_message.Message,), {
  'DESCRIPTOR' : _UPSTREAMBINDCONFIG,
  '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.UpstreamBindConfig)
  })
_sym_db.RegisterMessage(UpstreamBindConfig)

UpstreamConnectionOptions = _reflection.GeneratedProtocolMessageType('UpstreamConnectionOptions', (_message.Message,), {
  'DESCRIPTOR' : _UPSTREAMCONNECTIONOPTIONS,
  '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.UpstreamConnectionOptions)
  })
_sym_db.RegisterMessage(UpstreamConnectionOptions)

TrackClusterStats = _reflection.GeneratedProtocolMessageType('TrackClusterStats', (_message.Message,), {
  'DESCRIPTOR' : _TRACKCLUSTERSTATS,
  '__module__' : 'envoy.config.cluster.v4alpha.cluster_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.TrackClusterStats)
  })
_sym_db.RegisterMessage(TrackClusterStats)


DESCRIPTOR._options = None
_CLUSTERCOLLECTION._options = None
_CLUSTER_TRANSPORTSOCKETMATCH.fields_by_name['name']._options = None
_CLUSTER_TRANSPORTSOCKETMATCH._options = None
_CLUSTER_CUSTOMCLUSTERTYPE.fields_by_name['name']._options = None
_CLUSTER_CUSTOMCLUSTERTYPE._options = None
_CLUSTER_EDSCLUSTERCONFIG._options = None
_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR.fields_by_name['fallback_policy']._options = None
_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR._options = None
_CLUSTER_LBSUBSETCONFIG.fields_by_name['fallback_policy']._options = None
_CLUSTER_LBSUBSETCONFIG._options = None
_CLUSTER_LEASTREQUESTLBCONFIG.fields_by_name['choice_count']._options = None
_CLUSTER_LEASTREQUESTLBCONFIG._options = None
_CLUSTER_RINGHASHLBCONFIG.fields_by_name['minimum_ring_size']._options = None
_CLUSTER_RINGHASHLBCONFIG.fields_by_name['hash_function']._options = None
_CLUSTER_RINGHASHLBCONFIG.fields_by_name['maximum_ring_size']._options = None
_CLUSTER_RINGHASHLBCONFIG._options = None
_CLUSTER_MAGLEVLBCONFIG._options = None
_CLUSTER_ORIGINALDSTLBCONFIG._options = None
_CLUSTER_COMMONLBCONFIG_ZONEAWARELBCONFIG._options = None
_CLUSTER_COMMONLBCONFIG_LOCALITYWEIGHTEDLBCONFIG._options = None
_CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG.fields_by_name['hash_balance_factor']._options = None
_CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG._options = None
_CLUSTER_COMMONLBCONFIG._options = None
_CLUSTER_REFRESHRATE.fields_by_name['base_interval']._options = None
_CLUSTER_REFRESHRATE.fields_by_name['max_interval']._options = None
_CLUSTER_REFRESHRATE._options = None
_CLUSTER_PRECONNECTPOLICY.fields_by_name['per_upstream_preconnect_ratio']._options = None
_CLUSTER_PRECONNECTPOLICY.fields_by_name['predictive_preconnect_ratio']._options = None
_CLUSTER_PRECONNECTPOLICY._options = None
_CLUSTER_TYPEDEXTENSIONPROTOCOLOPTIONSENTRY._options = None
_CLUSTER.fields_by_name['name']._options = None
_CLUSTER.fields_by_name['type']._options = None
_CLUSTER.fields_by_name['connect_timeout']._options = None
_CLUSTER.fields_by_name['per_connection_buffer_limit_bytes']._options = None
_CLUSTER.fields_by_name['lb_policy']._options = None
_CLUSTER.fields_by_name['dns_refresh_rate']._options = None
_CLUSTER.fields_by_name['dns_lookup_family']._options = None
_CLUSTER.fields_by_name['cleanup_interval']._options = None
_CLUSTER._options = None
_LOADBALANCINGPOLICY_POLICY._options = None
_LOADBALANCINGPOLICY._options = None
_UPSTREAMBINDCONFIG._options = None
_UPSTREAMCONNECTIONOPTIONS._options = None
_TRACKCLUSTERSTATS._options = None
# @@protoc_insertion_point(module_scope)
